/**************************************************************************
 * CLASS:		MiscDragView
 * PROGRAMMER:	Todd Thomas			(todd@avocado.cuc.ab.ca)
 * DATE:		Nov 25, 1993
 * VERSION:		0.1
 *		
 *	MiscDragView is an abstract class (cannot be used as is) designed to be  
 * easily extensible. Please refer to the docs for a more indepth description.
 *
 * To make any subclass useable for both source and destination dragging:
 *
 * 		-override initFrame: to register the draggingTypes that your view 	
 *			will accept.
 *		-override setupForSourceDrag to choose the pasteboard, put data on it,
 *			and choose the image you would like to be dragged
 *		-override performDragOperation: sender to get the data from the
 *			pasteboard 
 *	
 *	The above is the minimum needed, but you'll likely want to override
 * other methods to check whether incoming draggings are acceptable, etc.
 *
 * 	Finally, the delegate (if there is one) will be sent messages like: 
 * sourceDragInitiated:, sourceDragFinished:, destinationDragInitiated:,
 * destinationDragFinished. The skeleton of this code came from the 
 * NW_DragLab example (Greg Burd and Randy Nelson...thanks for sharing your 
 * code). 
 *
 * This object is included in the MiscKit by permission from the author
 * and its use is governed by the MiscKit license, found in the file
 * "LICENSE.rtf" in the MiscKit distribution.  Please refer to that file
 * for a list of all applicable permissions and restrictions.
 ***************************************************************************/

#import <appkit/appkit.h>


@interface MiscDragView : View  
{
    id  delegate; 
	id  dragPB;	
	id  dragImage;				
	BOOL  allowSourceDragging, allowDestinationDragging;
	BOOL  acceptForeignDrag, acceptLocalDrag;
	BOOL  acceptSelfDrag, retainData;
}

//-------------------- Methods to get things set up 
- initFrame:(const NXRect *)frameRect;
- awake;
- free;

//-------------------- Options
- setAllowSourceDragging: (BOOL)aBool;
- (BOOL)allowSourceDragging;
- setAllowDestinationDragging: (BOOL)aBool;
- (BOOL)allowDestinationDragging;
- setAcceptForeignDrag: (BOOL)aBool;
- (BOOL)acceptForeignDrag;
- setAcceptLocalDrag: (BOOL)aBool;
- (BOOL)acceptLocalDrag;
- setAcceptSelfDrag: (BOOL)aBool;
- (BOOL)acceptSelfDrag;
- setRetainData: (BOOL)aBool;
- (BOOL)retainData;

//-------------------- Methods for source dragging 
- mouseDown:(NXEvent *)theEvent;
- (BOOL)setupForSourceDrag;
- calculateDragPoint: (NXPoint *)dragPoint andOffset: (NXPoint *)offset;
- (NXDragOperation)draggingSourceOperationMaskForLocal:(BOOL)flag;
- draggedImage:(NXImage *)image beganAt:(NXPoint *)screenPoint;
- draggedImage:(NXImage *)image endedAt:(NXPoint *)screenPoint 
		deposited:(BOOL)flag;
		
//-------------------- Methods for destination dragging */
- (NXDragOperation)draggingEntered:sender;
- (NXDragOperation)draggingUpdated:sender;
- draggingExited:sender;
- (BOOL)prepareForDragOperation:sender;
- (BOOL)performDragOperation:sender;
- concludeDragOperation:sender;

//-------------------- Basic useful methods 
- (BOOL)acceptsFirstMouse;
- (BOOL)shouldDelayWindowOrderingForEvent:(NXEvent *)theEvent;

//-------------------- Delegate methods 
- delegate;
- setDelegate: theDelegate;
- sourceDragInitiated: view;
- sourceDragFinished: (BOOL)success;
- destinationDragInitiated: view;
- destinationDragFinished: (BOOL)success;

//-------------------- Archiving methods
- read: (NXTypedStream *)stream;
- write: (NXTypedStream *)stream;

@end
