/***************************************************************************
 * CLASS:		MiscImageView
 * PROGRAMMER:	Todd Thomas			(todd@avocado.cuc.ab.ca)
 * DATE:		Nov 25, 1993
 * VERSION:		0.1
 *
 * 	This class was originally for an better "IconBuilder", but was extended
 * to be a more generally useful object capable to displaying an NXImage. You   	
 * can also change the border (default is NX_BEZEL) and the background color. 
 * If the image does not fit in the view it is scaled to fit (thanks to 
 * scaling code that maintains the image's original aspect ratio, from 	
 * Don_Yacktman@byu.edu). If the view is larger, the image is centered. 
 * If you can think of anything I have blatantly missed or you would like to
 * see contained in this object, or even if you find it useful, drop me a note.
 *
 * This object is included in the MiscKit by permission from the author
 * and its use is governed by the MiscKit license, found in the file
 * "LICENSE.rtf" in the MiscKit distribution.  Please refer to that file
 * for a list of all applicable permissions and restrictions.
 ***************************************************************************/

#import <appkit/appkit.h>
#import "MiscDragView.h"


@interface MiscImageView : MiscDragView
{
	id  ivImage;					// the displayed image
	NXSize  ivSize;					// real size of the image
	NXSize  scaledSize;				// scaled size depending upon view's bounds
    NXColor  backgroundColor;		// current background color
	int  border;					// current border type
	BOOL  drawBackground;			// for use with writePSCodeInside:
}

- initFrame: (const NXRect *)frameRect;
- free;
- setImage: (NXImage *)anImage;
- setImageByFilename: (char *)aFilename;
- (NXImage *)image;
- setBackgroundColor: (NXColor)someColor;
- (NXColor)backgroundColor;
- setDrawBackground: (BOOL)aBool;
- (BOOL)drawBackground;
- setBorderType: (int)aType;
- (int)borderType;
- drawSelf: (const NXRect *)rects :(int)rectCount;
- read: (NXTypedStream *)stream;
- write: (NXTypedStream *)stream;

@end
