//
//	MiscInfoController.h -- a class to handle the guts under an Info menu
//		Written by Don Yacktman (c) 1994 by Don Yacktman.
//				Version 1.0.  All rights reserved.
//
//		This notice may not be removed from this source code.
//
//	This object is included in the MiscKit by permission from the author
//	and its use is governed by the MiscKit license, found in the file
//	"LICENSE.rtf" in the MiscKit distribution.  Please refer to that file
//	for a list of all applicable permissions and restrictions.
//	

#import <appkit/appkit.h>

// This object uses a NXStringTable to hold all the localizeable things
// that we would want to have.  It's expected that you connect up a
// string table in the .nib for this object.
//
// Here is a list of the keys that you can and should put in the table:
//	Version			- string to represent version number on info panel
//	VersionDate		- string to represent date of current version (info panel)
//
//	NotRegistered	- Standard invalid key written out:  "Not registered."
//	Unreg			- "This Copy Is Unregistered"  if no valid key given
//	Reg				- "Copy #%s is registered"  The serial num is inserted.
//
//	Warning			- "Warning"		(Alert panel title)
//	OK				- "OK"			(Alert panel button)
//	OKForever		- "OK Forever"	(Alert panel button)
//	Abort			- "Abort"		(Alert panel button)
//
//	CantReg			- Alert panel text:  can't write keyfile in app wrapper
//	BadRegNum		- Alert panel text:  registration number is invalid
//	Clobber			- Alert panel text:  compose window will be clobbered
//
//	AuthorEMail		- e-mail address to whom feedback should be sent
//	AuthorName		- Appelation used to address person feedback goes to
//	MailMessage		- Text of email message to send feedback to; should have
//						a %s at the start to address the feedback recipient
//						and a second %s in the body to bring out the name
//						of the application.

#define MISC_UNREG_SERIAL_NUM "NREG" // string to use for an unregistered copy

#define MISC_KEY_FILE_NAME "key" // file name inside app wrapper;
		// this file holds the license key

#define MISC_KEY_DEFAULT "LicenseKey" // name of NX default that holds keys


@interface MiscInfoController : Object
{
    id	strings;		// localized strings -- see docs as to what's needed

    id	infoPanel;
	id  niftyView;			// animated view inside of an info panel
	id  versionText;		// textfield to give app version number
	id  versionDateText;	// textfield to give app version date

    id	registerPanel;	// basic registration panel
	id  regText;		// textfield in the register panel to give serial num
	id  regNumText;		// textfield in register panel where user types ser num

    id	orderFormPanel;	// basic order form panel
	id  costText;		// textfield to give extended cost of the license(s)

	id _keyFileName;	// MiscString -- path to key file inside app wrapper
	id _key				// MiscString -- current license key
	id _serialNum;		// MiscString -- serial number corresponding to key
}

+ initialize;
- init;
- niftyView;
- readKey;
- writeKey;
- readKeyFromFile;
- writeKeyToFile;
- infoPanel;
- setUpNotRegisteredText;
- setUpRegisteredText;
- registerPanel;
- orderFormPanel;
- (const char *)versionString;
- info:sender;
- readme:sender;
- license:sender;
- orderForm:sender;
- costCalc:sender;
- printOrderForm:sender;
- registration:sender;
- (BOOL)notRegistered;
- (BOOL)keyOK;
- registerApp:sender;
- cancelRegistration:sender;
- suggestion:sender;

@end
