//
//	MiscInfoController.m -- a class to handle the guts under an Info menu
//		Written by Don Yacktman (c) 1994 by Don Yacktman.
//				Version 1.0.  All rights reserved.
//
//		This notice may not be removed from this source code.
//
//	This object is included in the MiscKit by permission from the author
//	and its use is governed by the MiscKit license, found in the file
//	"LICENSE.rtf" in the MiscKit distribution.  Please refer to that file
//	for a list of all applicable permissions and restrictions.
//	

#import <misckit/misckit.h>

#define authorEmail [strings valueForStringKey:"AuthorEMail"]
#define _versionString [strings valueForStringKey:"Version"]

@implementation MiscInfoController

+ initialize
{
	static NXDefaultsVector MiscInfoControllerDefaults = {
		{ MISC_KEY_DEFAULT, MISC_DEFAULT_KEY },
		{ NULL }
	};
	NXRegisterDefaults([NXApp appName], MiscInfoControllerDefaults);
	return self;
}

- init				// make sure that *Panel is nil.
{
	self = [super init];
	infoPanel = nil;
	registerPanel = nil;
	orderFormPanel = nil;
	// get name of key file (inside app wrapper)
	_keyFileName = [MiscString newWithString:[NXApp appDirectory]];
	[_keyFileName cat:"/"];
	[_keyFileName cat:MISC_KEY_FILE_NAME];
	_key = [[MiscString alloc] init];
	_serialNum = [MiscString newWithString:MISC_UNREG_SERIAL_NUM];
	[self readKey];
	return self;
}

- niftyView { return niftyView; }

- readKey
{
	id keyString = [MiscString newWithString:
			NXGetDefaultValue([NXApp appName], MISC_KEY_DEFAULT)];
	if (![self readKeyFromFile]) {
		// ***** if read from file failed, then we need to try the one from
		// the defaults system.
	}
	// ***** even if not nil returned, may be invalid key...
	return self;
}

- writeKey
{
	[self writeKeyToFile];
	// **** this should only be written if the key is valid and single user,
	// in which case we do NOT write to key file!
	NXWriteDefault([NXApp appName], MISC_KEY_DEFAULT, [_key stringValue]);
	return self;
}

- readKeyFromFile
{
    NXTypedStream *typedStream;
    FILE *testFile;
	char *temp;

    testFile = fopen(keyFileName, "r"); // see if file exists; circumvents
    if (testFile == NULL) {
		if ([strings valueForStringKey:"NotRegistered"])
			strcpy(key, [strings valueForStringKey:"NotRegistered"]);
		else strcpy(key, "No key.");
		return nil;
	}
    fclose(testFile);
    typedStream = NXOpenTypedStreamForFile(keyFileName, NX_READONLY);
	NXReadTypes(typedStream, "*", &temp);
	if (temp) {
		[_key setStringValue:temp];
	} else {
		if ([strings valueForStringKey:"NotRegistered"]) {
			strcpy(key, [strings valueForStringKey:"NotRegistered"]);
		} else { strcpy(key, "No key."); }
		return nil;
	}
    NXCloseTypedStream(typedStream);
    return self;
}

- writeKeyToFile
{
	NXTypedStream *typedStream;

	typedStream = NXOpenTypedStreamForFile(keyFileName, NX_WRITEONLY);
	if (!typedStream) {
		// ***** should only put this up for network licenses...
		NXRunAlertPanel("writeKey",[strings valueForStringKey:"CantReg"],
			NULL, NULL, [strings valueForStringKey:"OK"]);
		return nil;
    }
	NXWriteTypes(typedStream, "*", &key);
	NXCloseTypedStream(typedStream);
	return self;
}

- infoPanel		// return the infoPanel, load it if needed.
{
	if( !infoPanel)
		[NXApp loadNibSection:"InfoPanel.nib" owner:self withNames:NO];
	return infoPanel;
}

- registerPanel		// return the registerPanel, load it if needed.
{
	if( !registerPanel)
		[NXApp loadNibSection:"Register.nib" owner:self withNames:NO];
	return registerPanel;
}

- orderFormPanel		// return the orderFormPanel, load it if needed.
{
	if( !orderFormPanel)
		[NXApp loadNibSection:"OrderForm.nib" owner:self withNames:NO];
	return orderFormPanel;
}

- (const char *)versionString
{
	return _versionString;
}

- info:sender		// make the info panel be up there.
{
	[[self infoPanel] orderFront:sender];
	[versionText setStringValue:_versionString];
	[versionDateText setStringValue:[strings valueForStringKey:"VersionDate"]];
	if ([niftyView respondsTo:@selector(start:)])
		[niftyView start:self]; // will stop automatically on close by
		// using window's delegate method -windowWillClose:
	return self;
}

- readme:sender	// make the README panel be up there.
{
	[[[NXHelpPanel new]
			showFile:"README.rtfd" atMarker:NULL]
			makeKeyAndOrderFront:self];
	return self;
}

- license:sender	// make the license panel be up there.
{
	[[[NXHelpPanel new]
			showFile:"License.rtfd" atMarker:NULL]
			makeKeyAndOrderFront:self];
	return self;
}

- orderForm:sender
{
	[[self orderFormPanel] makeKeyAndOrderFront:sender];
	return self;
}

- costCalc:sender
{	// override for more useful functions... right now, it's $10 for whatever.
	// (ie you really have to put something in here to get a useful order
	// form put together.)
	[costText setIntValue:10];
	return self;
}

- printOrderForm:sender	// Do -costCalc and then print orderForm.
{
	// calculate the cost (extensions, etc.) before printing.
	[self costCalc:self];
	// delay the print so that the button won't be highlighted
	// on the printout.
	[[sender window] perform:@selector(smartPrintPSCode:)
				with:self afterDelay:1 cancelPrevious:NO];
	return self;
}

- setUpNotRegisteredText
{
	[[regText setStringValue:[strings valueForStringKey:"Unreg"]]
			setTextGray:NX_WHITE];
	return self;
}

- setUpRegisteredText
{
	id tempStr = [[MiscString alloc]
			initFromFormat:[strings valueForStringKey:"Reg"],
			[_serialNum stringValue]];
	[[regText setStringValue:[tempStr stringValueAndFree]]
			setTextGray:NX_DKGRAY];
	return self;
}

- registration:sender
{
	[self registerPanel]; // make sure nib is loaded
	if ([self notRegistered]) [self setUpNotRegisteredText];
	else [self setUpRegisteredText];
	[[self registerPanel] makeFirstResponder:regNumText];
	if ([_key emptyString])
		[_key setStringValue:[strings valueForStringKey:"NotRegistered"]];
	[regNumText setStringValue:[_key stringValue]];
	[regNumText selectText:self];
	[NXApp runModalFor:[self registerPanel]];
	return self;
}

- (BOOL)notRegistered
{	// determine if the user has registered.	
	if (![_key emptyString] && [self keyOK]) {
		[self setUpRegisteredText];
		return NO;
	}
	[self setUpNotRegisteredText];
	return YES;
}

- (BOOL)keyOK
{	// override to check the "_key" variable (a MiscString) for OK values...
	// you should set the stringValue of _serialNum to the serial number
	// that corresponds to the key.  (ie, the serial num should be embedded
	// in the key in some way along with everything else.)
	return YES;
	// Why don't I provide a mechanism here?  Because the code would allow
	// any fool to come up with fake keys.  So you have to write your own
	// code for this method for your security.  If you would like me to
	// write you a simple key encoding mechanism, I'd be happy to do so;
	// just contact me:  Don_Yacktman@byu.edu.  I will charge you for the
	// service, but I don't ask much.  (It's based upon how long it takes
	// me to write it, and since I already have some algorithms, I could use
	// a simpler method that's a permutation of what I already have and
	// your cost wouldn't be much more that about $15.  Contact me...)
	// One other note:  A hacker could always come in and disable the
	// keys.  We don't try to circumvent this at all, so you might want
	// to use a more complex integrity method to fool hackers.  Again, I
	// can give suggestions to the truly paranoid, for a fee.  However,
	// unless you're really paranoid, there is no need for this since a
	// hacker will eventually crack whatever scheme you use, and this
	// scheme is sufficient to keep everyone else honest, I believe.
}

- registerApp:sender		// accept registration...or not...
{
	BOOL runAlert = NO;
	[_key setStringValue:[regNumText stringValue]]; // grab the key they typed
	if ([self keyOK]) { // if OK, we write it out
		id tmpStr = [[MiscString alloc] init];
		[self writeKey];
		[tmpStr setFromFormat:[strings valueForStringKey:"Reg"], serialNum];
		[[regText setStringValue:[tmpStr stringValue]]
				setTextGray:NX_DKGRAY];
		[tmpStr free];
	} else { // if NOT OK, we remove panel and show an alert panel.
		[self writeKey];
		[[regText setStringValue:[strings valueForStringKey:"Unreg"]]
				setTextGray:NX_WHITE];
		runAlert = YES;
	}
	[registerPanel orderOut:self];
	[NXApp stopModal];
	if (runAlert) NXRunAlertPanel(NULL,
			[strings valueForStringKey:"BadRegNum"], NULL, NULL, NULL);
	return self;
}

- cancelRegistration:sender		// cancel registration modal loop...
{
	[registerPanel orderOut:self];
	[NXApp stopModal];
	return self;
}

// call() macro sends a message from the app's Speaker to Mail.app to
// perform the various Mail.app functions.
#define call(a,b) [s performRemoteMethod:a with:b length:strlen(b)+1]
- suggestion:sender	// This is pretty much lifted from Opener.
{
	id body = [[MiscString alloc] init];
	id subject = [[MiscString alloc] init];
    id s = [NXApp appSpeaker];
	int x = 1; int doit = NO;
	id tmpstr = [MiscString newString:
			NXGetDefaultValue([NXApp appName], "MailClobber")];

	// Determine if we clobber, abort, or skip warning panel
	if ([tmpstr emptyString]) doit = YES;
	else if ([tmpstr cmp:"OK"]) doit = YES;
	if (doit) x = NXRunAlertPanel([strings valueForStringKey:"Warning"],
		[strings valueForStringKey:"Clobber"],
		[strings valueForStringKey:"OK"],
		[strings valueForStringKey:"OKForever"],
		[strings valueForStringKey:"Abort"]);
	if (x == 0) NXWriteDefault ([NXApp appName], "MailClobber", "OK");
	if (x == -1) return self; // abort

	// prepare the message to send
    [subject setFromFormat:"Comments and suggestions for ``%s'' ",
			[NXApp appName]];
	[subject catStrings:_versionString, " (", [_serialNum stringValue], ")"];
	[body setFromFormat:[strings valueForStringKey:"MailMessage"],
			[strings valueForStringKey:"AuthorName"], [NXApp appName]];
    [body catStrings:[NXApp userRealName], "\n"];

	// launch mail, bring up a compose window if needed, and prepare
	// the message for the user.  They decide whether or not to deliver
	// it, and so on.
    NXPortFromName("Mail", NULL); // make sure app is launched
    [s setSendPort:NXPortFromName("MailSendDemo", NULL)];
    call("setTo:", authorEmail); // will bring up a compose window if needed
    call("setSubject:", [subject stringValue]);
    call("setBody:", [body stringValue]);
    [subject free];
    return self;
}

@end
