/* MiscSwapSubviewController.h				 
 *
 * A very simple class for controlling swapAble views. A subclass is a must 
 * to easily work with the MiscSwapViewBy... classes.
 *
 * Usage: Just create a instance and connect it to the view that holds the
 *		  should swap in when the trigger object is activated.
 *		  As an alternative you can set the tag this view is related to by 
 *		  creating an object with the right tag and setting it to be the
 *		  trigger. Its very easy to do this with the IB.
 *
 * Notes: If you create your own viewController you should really make a sub-
 *		  class of this object. Otherwise you might get problems if you do not
 *		  implement all the methods because the swapViews are very lazy in
 *		  respondsTo checking.
 *
 *		  When the view willSwapOut you should ensure that no colorWells are
 *		  activated! This may cause some trouble or inconsistency.
 *
 * Written by: 		Thomas Engel
 * Created:    		24.01.1994 (Copyleft)
 * Last Modified: 	24.01.1994
 */

#import <appkit/appkit.h>

@interface MiscSwapSubviewController:Object
{
	id		swapView;
	id		view;
	id		trigger;
	int		triggerTag;
}

- setSwapView:anObject;
- swapView;
- setView:anObject;
- view;
- setTrigger:anObject;
- trigger;
- setTriggerTag:(int)tag;
- (int)triggerTag;

// These revert/ok msg are send to setup/save the contents of a view.
// Only the revert msg is invoked by default. If you have to store some
// data when swapping out implement a [self ok:self] msg inside willSwapOut.

- ok:sender;
- revert:sender;

// These methods are used to inform this class of its fate.
// The willSwapIn method calls [self revert] by default.

- willSwapIn;
- willSwapOut;
- didSwapIn;
- didSwapOut;

- awakeFromNib;

@end

/*
 * History: 24.01.94 Made it a Misc object and changed it to work with the
 *					 new Misc stuff.
 *
 *			09.01.94 Added the ok/revert stuff.
 *
 *			08.01.94 Derived from my old swapViewdelegate. The code+methods
 *					 were cleaned up a bit.
 *
 *
 * Bugs: - No read/write.
 */