/* MiscSwapView.h
 *
 * This subclass of View is able to swap different views into itself. It's
 * used to implement any kind of multipage windows. (Inspectors, Prefs...)
 * This object is a redesign of Greg Bruds swapView.
 *
 * Usage: Just instantiate a view inside IB and tell it what view to show
 *		  next. The MiscSwapView will take care of putting the views back where
 *		  they came from once they will swap out again.
 *
 * Notes: This view by default resizes its subview to it current size. But you
 *		  can decide how they are resized by the default NeXTSETP view resizing
 *		  settings.
 *		  
 *		  Right now you can set the buffering flag but it will not work because
 *		  there is a problem with resizing.
 *		  This may be a bug but I decided to save memory and allow resizing 
 *		  over the slightly faster swapping. With fast hardware this might not
 *		  be of any concern at all...so keep the ports rolling:HP, Sun, PPC...?
 *
 * Improved by:		Thomas Engel
 * First changes:   24.01.1994 (Copyleft)
 * Last modified: 	24.01.1994
 */

#import <appkit/appkit.h>

@interface MiscSwapView:View
{
	id		subview;
	id		subviewsHomeWindow;
	id		delegate;
	float	backgroundGray;
}

// Basic view init and freeing

- init;
- initFrame:(const NXRect *)frameRect;
- free;

// basic instance-control method and delegate setting

- setDelegate:(id)anObject;
- delegate;
- setBackgroundGray:(float)aColor;
- (float)backgroundGray;
- subviewsHomeWindow;

// the real work..swapping in action

- setSubview:aView;
- subview;

- write:(NXTypedStream *)stream;
- read:(NXTypedStream *)stream;

@end

// This method might be implemented by the delegate but is quite useless here
// because somebody has to trigger the swapping an he knows when something 
// changes.
// But once we will handle swapping on our own we might need this.

@interface Object(MiscSwapViewDelegate)

- viewWillSwap:sender;
- viewDidSwap:sender;

@end

/*
 * History: 24.01.94 Took my old swapView and wrote it again...
 *
 *			21.01.94 Did some work to the resizing of swapView.
 *
 *			19.11.93 Started to do some cleanups in this HeaderFile and
 *			 		 resizing got implemented into the object.
 *
 *			17.11.93 Played around with resizing and found it right.
 *
 *
 * Bugs: - There might be problems with swapping out a view with an active
 *		   colorWell. Here some should take care a deactive them.
 *		   You might use the delegate and viewWillSwap.
 *		   Normally you will use subviewControllers and they will recieve
 *		   swapIn/Out too and can take care of that inside their revert/ok
 *		   methods or what ever.
 *
 *		 - Read & write do nothing at all. I'm not even sure wether they should
 *		   do something ?
 */
