/* MiscSwapView.m
 *
 * This subclass of View is able to swap different views into itself. It's
 * used to implement any kind of multipage windows. (Inspectors, Prefs...)
 *
 * For more interface-info see the header file. More in depth information
 * can be found here in the source-code.
 *
 * Improved by:		Thomas Engel
 * First changes:   24.01.1994 (Copyleft)
 * Last modified: 	24.01.1994
 */

#import "MiscSwapView.h"
 
@implementation MiscSwapView

- init
{
	NXRect theFrame = {{0.0, 0.0}, {0.0, 0.0}};
	return [self initFrame:&theFrame];
}

- initFrame:(const NXRect *)frameRect
{
	// Designated initilizer. We will set allow resizing by default and
	// we will draw in Lightgray if we have to swap 'nil' in.

	self = [super initFrame:frameRect];
	if( !self ) return self;

	backgroundGray = NX_LTGRAY;
	[self setAutoresizeSubviews:YES];
	
	return self;
}

- free
{
	return [super free];
}

- setDelegate:(id)anObject
{
	delegate = anObject;
	return self;
}

- delegate
{
	return delegate;
}

- setBackgroundGray:(float)aGray
{
	backgroundGray = aGray;
	return self;
}

- (float)backgroundGray
{
	return backgroundGray;
}

- subviewsHomeWindow;
{
	return subviewsHomeWindow;
}

- setSubview:aView
{
 	// This is the real method !! 
 	// Here we process the finding of the swapping and resizing.
	// If the new view is different from our current subview we should
	// put the current back where it came from.
	// We won't resize it because it should not matter anyway.
	
	if( aView != subview )
	{
		if( subview && subviewsHomeWindow )
		{
			[subview removeFromSuperview];
			[[subviewsHomeWindow contentView] addSubview:subview];
		}
	
		// No real subview? So clean up the background. This is done by
		// filling the view bounds with the backgroundGray we did set.
	
		subview = aView;
		
		if( !subview )
		{
			subviewsHomeWindow = nil;
	
			[self lockFocus];
   		 	PSsetgray( backgroundGray );
   		 	NXRectFill(&bounds);
			[self unlockFocus];
		}

		// Otherwise we have a new subview so lets remove it form its home-
		// window, resize it and align it to our 0,0 corner.
		
		else
		{
	/*		[self lockFocus];
   		 	PSsetgray(backgroundGray);
   		 	NXRectFill(&bounds);
			[self unlockFocus];  
   */
			subviewsHomeWindow = [subview window];
			[subview removeFromSuperview];
			[self addSubview:subview];
			[subview moveTo:0.0 :0.0];
			[subview sizeTo:bounds.size.width :bounds.size.height];
			[self display];
		}
		// Let the windowServer catch up to the changes we made (yawn...)
		// And show our nice new window
		
		NXPing();
		[[self window] flushWindow];
	}
	return self;
}

- subview
{
	// Maybe it's not so nice to name our subview just subview because the
	// is a method subviewS for every view and one might mistype this method
	// name. But it really does what it says. A swapView can have only one 
	// subview..and we will return this one.
	
	return subview;
}

- write:(NXTypedStream *)stream
{
	return self;
}

- read:(NXTypedStream *)stream
{
	return self;
}

@end

/*
 * History: 24.01.94 Redesign from my old swapView.
 *
 *			21.01.94 Added the resizing job the Greg's swapView.
 *
 * 
 * Notes: If we might implement the offScreen drawing some day (maybe I will)
 *		  The window that contains the new subview will have to the Retained
 *		  and not deferred. Otherwise there will be not gstate to copy from
 *		  with the following code:
 *
 *			gstate = [[subview window] gState];
 *			[subview getFrame:&theFrame];
 *			[self lockFocus];
 *			PScomposite( (float)theFrame.origin.x,
 *						 (float)theFrame.origin.y,
 *						 (float)theFrame.size.width,
 *						 (float)theFrame.size.height,
 *						 (int)gstate,
 *						 (float)1.0,
 *						 (float)1.0,
 *						 (int)NX_COPY );
 *			[self unlockFocus];
 *
 *		  Rigth now I have now idea how to provide resizing with those views.
 *
 *
 * Bugs: - Could be. Yes.
 */