/* MiscSwapViewByObject.h				 
 *
 * This is a class can handle swapping of different subview (controlled by
 * MiscSwapSubiewController's) into ourself by comparing trigger objects.
 *
 * Usage: To work properly every subviews controller has to register itself
 *		  at the corresponding swapView. The object triggering the swap
 *		  should invoke the sV-object and this one has to decide which 
 *   	  subviewController has to come to front.
 *		  The trigger instance stores the triggering object to have it at
 *		  hand when a findController(..) needs it to make the decision.
 *
 *		  For the first time the swapView will be uninitialized! The app
 *		  has to trigger some kind of default swap maybe by a 
 *		  [swapView swapAction:defaultObject];
 *
 * Notes: To implement a different controller-finding behavior you should only
 *		  override the findControllerByTag/object methods. They should return
 *		  the swapSubviewController to take next ... or nil.
 *		  Sometime swapAction can provide a trigger dejustment too.
 *
 * Written by: 		Thomas Engel
 * Created:    		24.01.1994 (Copyleft)
 * Last modified: 	24.01.1994
 */

#import "MiscSwapView.h"

@interface MiscSwapViewByObject:MiscSwapView
{
	id		trigger;
	id		controllers;
	id		currentController;	
	BOOL	tagComparison;
}

- initFrame:(const NXRect *)frameRect;
- free;

- trigger;

/*
 * swapAction is invoked by the action-buttons.
 */
 
- swapAction:sender;

// Here are some methods that allow some subviewController handling.
// There should be no need to change the list by hand!
 
- addController:sender;
- removeController:sender;
- removeAllControllers;
- controllers;
- currentController;

- setTagComparison:(BOOL)flag;
- (BOOL)doesTagComparison;

// These are the methods that decides which controller to show activate next.
// Here is the place to add some custom behavior. The methods byTag/object
// should work with no pain in any subclass too. For details see the popup and
// matrix subclasses of this object
 
- findController;
- findControllerByTag;
- findControllerByObject;

@end

/*
 * History: 24.01.94 Made it a subclass of MiscSwapView
 *
 *			08.01.94 Switched to tagComparison for better reading.
 *					 choosesByTagFirst was not that nice.
 *
 *			21.12.93 Derived from my old swapPopManager this is a simple usable
 *					 and subcallable object.
 *					 Some viewController handling methods added.
 *
 *			04.12.93 Added the delegates methods.
 *
 *  		04.11.93 First methods hacked together.
 *
 *
 * Bugs: - read/write methods are missing! Shame on me.
 */