/* MiscSwapViewByPopUp.m				 
 *
 * This is a SwapView that can handle popUps either by tag or by title.
 * If a tag is not 0 it will try to choose the viewController by title.
 *
 * For more interface-info see the header file. More in depth information
 * can be found here in the source-code.
 *
 * Written by: 		Thomas Engel
 * Created:    		24.01.1994 (Copyleft)
 * Last modified: 	24.01.1994
 */

#import "MiscSwapViewByPopUp.h"

@implementation MiscSwapViewByPopUp

- setPopUpCover:anObject
{
	// Because it is not possible to set the popUpMenus actionMethod inside
	// IB we have to do it here. But who cares. It's nicer this way anyway.
	
	popUpCover = anObject;
    [[popUpCover target] setTarget:self];
	[[popUpCover target] setAction:@selector(swapAction:)];
	return self;
}

- popUpCover
{
	return popUpCover;
}

- swapAction:sender
{
	// We find the right popUp item and if really have one we can simply set 
	// the trigger to the right object and use the simple ..byTag/obj methods
	// provided by our super-class. 
	
	id	aPopUpItem;

	aPopUpItem = [self realTrigger];
	if( aPopUpItem ) sender = aPopUpItem;
	
	return [super swapAction:sender];
}

- realTrigger
{
	// Here we try to find the currently selected popUpItem. This is the
	// real trigger of a action.
	// The first time a popUp appears there is no selected menuCell. This
	// is why we have to check the popUpCover for the first time we get here.
	
	id	realTrigger;
	id	popUpMatrix;
	id	cellList;
	id	aCell;
	const char	*title;
	int	i;
	
	popUpMatrix = [[popUpCover target] itemList];
	realTrigger = [popUpMatrix selectedCell];
	
	if( !realTrigger )
	{
		cellList = [popUpMatrix cellList];
		title = [popUpCover title];
	
		for( i=0; i<[cellList count]; i++ )
		{
			aCell = [cellList objectAt:i];
			if( strcmp( [aCell title], title ) == 0 )
			{
				realTrigger = aCell;
				break;
			}
		}
	}
	
	// Being envoked by keyboard causes the right popUp item to be
	// selected but does not change the covers title. This is what we do
	// here. Maybe not always needed but who cares.
	
	[popUpCover setTitle:[realTrigger title]];
	
	return realTrigger;	
}

@end

/*
 * History: 24.01.94 Made it MiscSwap conform.
 *
 *			08.01.94 Renamed it to swapPopUpController and did some real
 *					 nice redesign.
 *
 *			20.12.93 Enlightened the controller to check the tags if they are
 *					 set. This helps to localize apps.
 *
 *			04.12.93 Added a delegate to this class the enable better 
 *					 command-key handling.
 *
 *			04.11.93 First steps to a general-purpose swapPopManager.
 *
 *
 * Bugs: - does only handle real popUps. PullDowns might not realy work 
 *		   because I always set the title inside the trigger method. Hmm
 *		   Maybe its better to write a seperate pullDown Controller!
 */